#!/usr/bin/perl -w

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
#



####
# CONFIG
####

$tmp_file = "/tmp/irc_mp3";

# if you want to announce everytime a new song comes on, set this to 1.  
# if you just wanna announce via "/music", set this to 0.
$announce_regularly = 1;
$interval = 1200000;		# (default = every 20 mins)

# Do you want it to display the track it's on, as well?  I keep my mp3s sorted
# by album, and usually just do something like 
# `mpg123 /mnt/mp3/Therapy-Troublegum/*` to have it play the entire album, so
# it comes in handy for me.  Set this to 1 if you want it.  If you listen
# to a lot of single mp3s (totally random), then assigning them track numbers
# would make no sense; set this to 0. 
$disp_track = 1;

####
# END CONFIG
####





IRC::register("mpg123 script", "0.2", "", "");
IRC::print "Loading mpg123 script 0.2...\n";
IRC::add_command_handler("announce", "announce");
IRC::add_timeout_handler($interval, "announce")	if ($announce_regularly);

sub announce {
	my ($title, $artist, $album, $track) = &get_song_info;
	return 1 if (!$title || !$artist || !$album);

	my $once = 0;
	foreach (&get_chan_list) {
		if ($disp_track) {
			IRC::send_raw "PRIVMSG $_ :\001ACTION is listening to \"$title\", by $artist [$album:$track]\001\n";
			IRC::print "/me is listening to \"$title\", by $artist [$album:$track]\n" if (!$once);
			$once = 1;
		}
		else {
			IRC::send_raw "PRIVMSG $_ :\001ACTION is listening to \"$title\", by $artist [$album]\001\n";
			IRC::print "/me is listening to \"$title\", by $artist [$album]\n" if (!$once);
			$once = 1;
		}
	}

	return 0;
}




sub get_chan_list {
	my @chanlist = IRC::channel_list();
	my %validchans;
	my @ret_list;

	foreach (@chanlist) {	
		$validchans{$_} = 1		if ($_ =~ /^#/)
	}

  foreach (keys %validchans) {
		push (@ret_list, $_);
	}	
	
	return @ret_list;
}	




sub get_song_info {
  open(TMP, $tmp_file) || return;
	my ($artist, $title, $album, $track_num);
		
	while (<TMP>) {
			
		# parse for title && artist
		if ($_ =~ /^Title  : /) {
			$_ =~ s/ {2,}//g;
			$_ =~ /^Title: ?(.*)Artist: ?(.*)$/;
			$title = $1;
			$artist = $2;
		}

		# parse for album name
		elsif ($_ =~ /^Album  : /) {
			$_ =~ s/ {2,}//g;
			$_ =~ /^Album: ?(.*)Year: ?.*$/;
			$album = $1;
		}
	
		# parse for track number
		elsif ($_ =~ /^track/) {
			$_ =~ /^track: (.+)$/;
			$track_num = $1;
		}	
	}																	

	close(TMP);
	return ($title, $artist, $album, $track_num);
}		

